Module Name: src
Committed By: cegger
Date: Thu May 7 09:23:01 UTC 2009
Modified Files:
src/sys/dev: audiobell.c audiobellvar.h
Log Message:
struct device * -> device_t
comment says, first argument of audiobell is a device, so make it a device.
To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/sys/dev/audiobell.c
cvs rdiff -u -r1.4 -r1.5 src/sys/dev/audiobellvar.h
Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Modified files:
Index: src/sys/dev/audiobell.c
diff -u src/sys/dev/audiobell.c:1.6 src/sys/dev/audiobell.c:1.7
--- src/sys/dev/audiobell.c:1.6 Wed Dec 17 20:51:34 2008
+++ src/sys/dev/audiobell.c Thu May 7 09:23:01 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: audiobell.c,v 1.6 2008/12/17 20:51:34 cegger Exp $ */
+/* $NetBSD: audiobell.c,v 1.7 2009/05/07 09:23:01 cegger Exp $ */
/*
* Copyright (c) 1999 Richard Earnshaw
@@ -31,7 +31,7 @@
*/
#include <sys/types.h>
-__KERNEL_RCSID(0, "$NetBSD: audiobell.c,v 1.6 2008/12/17 20:51:34 cegger Exp $");
+__KERNEL_RCSID(0, "$NetBSD: audiobell.c,v 1.7 2009/05/07 09:23:01 cegger Exp $");
#include <sys/audioio.h>
#include <sys/conf.h>
@@ -134,9 +134,9 @@
}
void
-audiobell(void *arg, u_int pitch, u_int period, u_int volume, int poll)
+audiobell(device_t arg, u_int pitch, u_int period, u_int volume, int poll)
{
- struct device *audio = arg;
+ device_t audio = arg;
uint8_t *buf;
struct uio auio;
struct iovec aiov;
Index: src/sys/dev/audiobellvar.h
diff -u src/sys/dev/audiobellvar.h:1.4 src/sys/dev/audiobellvar.h:1.5
--- src/sys/dev/audiobellvar.h:1.4 Sun Dec 11 12:20:53 2005
+++ src/sys/dev/audiobellvar.h Thu May 7 09:23:01 2009
@@ -1,4 +1,4 @@
-/* $NetBSD: audiobellvar.h,v 1.4 2005/12/11 12:20:53 christos Exp $ */
+/* $NetBSD: audiobellvar.h,v 1.5 2009/05/07 09:23:01 cegger Exp $ */
/*-
* Copyright (c) 2004 Ben Harris
@@ -29,7 +29,7 @@
/*
* To make a noise, call audiobell(dev, pitch, period, volume, poll).
* dev is a struct device * for the audio device to use.
* pitch is the pitch of the bell in Hz,
* period is the length in ms,
* volume is the amplitude in % of max,
@@ -38,4 +38,4 @@
* This function is designed to be passed to pckbd_hookup_bell() and
* equivalents.
*/
-extern void audiobell(void *, u_int, u_int, u_int, int);
+extern void audiobell(device_t, u_int, u_int, u_int, int);
@@ -29,7 +29,7 @@
/*
* To make a noise, call audiobell(dev, pitch, period, volume, poll).
- * dev is a struct device * for the audio device to use.
+ * dev is a device_t for the audio device to use.
* pitch is the pitch of the bell in Hz,
* period is the length in ms,